@@ -21,8 +21,10 @@ Usage::
     list_protections_paginator: ListProtectionsPaginator = client.get_paginator("list_protections")
     ```
 """
-from mypy_boto3_shield.client import ShieldClient, ShieldClient as Client
+from mypy_boto3_shield.client import ShieldClient
 from mypy_boto3_shield.paginator import ListAttacksPaginator, ListProtectionsPaginator
 
+Client = ShieldClient
+
 
 __all__ = ("Client", "ListAttacksPaginator", "ListProtectionsPaginator", "ShieldClient")
